@@ -18,6 +18,9 @@ class ftpUtil:
     __url_head="http://home.hddly.cn:90/stud/"
     __mutil= mysqlUtil()
 
+    def chk_file_exist_surl(self,surl,fdesc):
+        return self.__mutil.chk_file_exist_surl(surl,fdesc)
+
     def putfile_project(self, local_path, prj_id, stud_id, no_file,fdesc,surl):
         # # 要传输文件的路径
         # filepath = "./myname.jpg"
@@ -33,7 +36,7 @@ class ftpUtil:
                 duration=0
             fsize=os.path.getsize(local_path)
             # 根据文件大小fsize和时间duration，在数据库中判断是否已采集(>0)，是的话就返回，否则继续
-            iexist=self.__mutil.sftp_file_repeat(fdesc,fsize,duration)
+            iexist=self.__mutil.chk_file_exist(fdesc,fsize,duration)
             if iexist>0:
                 print("repeat：%s,%d,%f" % (fdesc,fsize,duration))
                 return
