@@ -4,6 +4,7 @@ import sys
 import pandas as pd
 from sqlalchemy import create_engine
 from sqlalchemy import text
+from redisUtil import redisUtil
 
 class mysqlUtil:
     __mysql_username = 'test'
@@ -12,6 +13,7 @@ class mysqlUtil:
     __mysql_ip = 'home.hddly.cn'
     __port = 53306
     __db = 'test'
+    __redis = redisUtil()
 
     def __init__(self):
         self.OpenDB(self.__db)
@@ -87,14 +89,23 @@ class mysqlUtil:
 
     def chk_file_exist_surl(self,surl,fdesc):
         if surl and fdesc:
+            surl = surl[0:99]  # 只取前100位
+            fdesc = fdesc[0:999]
+            # 先从redis中判断 是否存在，如果不存在，再从mysql中查找，找到的话添加到redis中
+            if self.__redis.sismember("surl",surl):
+                return 1
+            if self.__redis.sismember("fdesc",fdesc):
+                return 1
+
             # 判断float相等： abs(duration-123.31)<0.01
-            surl=surl[0:100] #只取前100位
             sql = "select id from sftp_files where surl='{}' or fdesc='{}' limit 1".format(surl,fdesc)
             connection = self.engine.connect()
             df = pd.read_sql(text(sql), con=connection)
             results = json.loads(df.to_json(orient='records'))
             if results and len(results) == 1:
                 # 记录采集重复信息
+                self.__redis.sadd("surl",surl)
+                self.__redis.sadd("fdesc",fdesc)
                 return 1
             else:
                 return 0
@@ -105,7 +116,7 @@ class mysqlUtil:
         try:
             df = pd.DataFrame(columns=['filename', 'url', 'stud', 'fdesc', 'fsize', 'duration', 'ftype','pid','surl'])
             # print(df)
-            surl=surl[0:100] #截取字符串前100个字符
+            surl=surl[0:99] #截取字符串前100个字符
             row1 = pd.DataFrame(
                 {'filename': filename, 'url': url, 'stud': stud, 'fdesc': fdesc, 'fsize': fsize, 'duration': duration,
                  'ftype': ftype,'pid':pid,'surl':surl}, index=[1])
